@@ -1,5 +1,6 @@
 /*
     SPDX-FileCopyrightText: 2018 Michael Heidelbach <ottwolt@gmail.com>
+    SPDX-FileCopyrightText: 2022 Adriaan de Groot <groot@kde.org>
 
     SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
@@ -18,6 +19,9 @@ class FileMetadataDateDisplayTest : public QObject
 private Q_SLOTS:
     void initTestCase();
 
+    /// Validate that KFormat produces the expected date strings
+    void validateDateFormats();
+
     void shouldDisplayLongAndShortDates();
     void shouldDisplayLongAndShortDates_data();
 
